From: "Pierre Muller" <muller@ics.u-strasbg.fr>
To: <gdb-patches@sourceware.org>
Subject: [RFA] set PROTOTYPED flag for pascal functions in dwarf2read.c
Date: Wed, 26 Sep 2007 12:49:00 -0000 [thread overview]
Message-ID: <003601c8003b$b9a3cf50$2ceb6df0$@u-strasbg.fr> (raw)
According to Jonas Maebe, all pascal functions are
prototyped (as are C++ and Java functions).
I did not find any code that really uses the fact
that a function is prototyped, but I am willing to
commit this after approval by dwarf2 maintainers
so that I can close one more bug report...
Pierre Muller
2007-09-26 Pierre Muller <muller@ics.u-strasbg.fr>
* Fix PR pascal/2231
dwarf2read.c (read_subroutine_type):
All pascal functions are prototyped.
Index: dwarf2read.c
===================================================================
RCS file: /cvs/src/src/gdb/dwarf2read.c,v
retrieving revision 1.231
diff -u -p -r1.231 dwarf2read.c
--- dwarf2read.c 5 Sep 2007 00:51:48 -0000 1.231
+++ dwarf2read.c 26 Sep 2007 12:38:19 -0000
@@ -4744,11 +4744,12 @@ read_subroutine_type (struct die_info *d
type = die_type (die, cu);
ftype = make_function_type (type, (struct type **) 0);
/* All functions in C++ and Java have prototypes. */
attr = dwarf2_attr (die, DW_AT_prototyped, cu);
if ((attr && (DW_UNSND (attr) != 0))
|| cu->language == language_cplus
- || cu->language == language_java)
+ || cu->language == language_java
+ || cu->language == language_pascal)
TYPE_FLAGS (ftype) |= TYPE_FLAG_PROTOTYPED;
if (die->child != NULL)
next reply other threads:[~2007-09-26 12:49 UTC|newest]
Thread overview: 3+ messages / expand[flat|nested] mbox.gz Atom feed top
2007-09-26 12:49 Pierre Muller [this message]
2007-09-26 12:57 ` Daniel Jacobowitz
2007-09-26 14:04 ` Pierre Muller
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to='003601c8003b$b9a3cf50$2ceb6df0$@u-strasbg.fr' \
--to=muller@ics.u-strasbg.fr \
--cc=gdb-patches@sourceware.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -4744,11 +4744,12 @@ read_subroutine_type (struct die_info *d
type = die_type (die, cu);
ftype = make_function_type (type, (struct type **) 0);
- /* All functions in C++ and Java have prototypes. */
+ /* All functions in C++, Pascal and Java have prototypes. */
attr = dwarf2_attr (die, DW_AT_prototyped, cu);
if ((attr && (DW_UNSND (attr) != 0))
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox